from .__main__ import decode_decisions, decode_statutes
from .statutes import load_statute, map_to_model
